pub(crate) fn current_system_time() -> SystemTimeExpand description
Return the current system time.
(This is a separate method for compatibility with wasm32.)
pub(crate) fn current_system_time() -> SystemTimeReturn the current system time.
(This is a separate method for compatibility with wasm32.)